@@ -3,8 +3,8 @@ ebuild internal constants
 """
 
 from snakeoil.osutils import pjoin
-from pkgcore import const
 
+from .. import const
 
 incrementals = (
     "ACCEPT_KEYWORDS", "ACCEPT_LICENSE", "CONFIG_PROTECT",
@@ -19,7 +19,7 @@ incrementals_unfinalized = ("USE",)
 metadata_keys = (
     "BDEPEND", "DEPEND", "RDEPEND", "PDEPEND",
     "DEFINED_PHASES", "DESCRIPTION", "EAPI", "HOMEPAGE",
-    "INHERITED", "IUSE", "KEYWORDS", "LICENSE", "PROPERTIES",
+    "INHERIT", "INHERITED", "IUSE", "KEYWORDS", "LICENSE", "PROPERTIES",
     "REQUIRED_USE", "RESTRICT", "SLOT", "SRC_URI", "_eclasses_",
 )
 
