@@ -20,24 +20,21 @@ __all__ = (
 
 import contextlib
 import errno
-from functools import partial, wraps
-import logging
-from itertools import chain
 import os
 import signal
-import sys
 import threading
 import traceback
+from functools import partial, wraps
+from itertools import chain
 
-from snakeoil import bash, fileutils, klass, process
-from snakeoil.osutils import abspath, normpath, pjoin
+from snakeoil import bash, fileutils, klass
+from snakeoil.osutils import pjoin
 from snakeoil.process import spawn
 
-from pkgcore import __file__, const, os_data
-from pkgcore.ebuild import const as e_const
-from pkgcore.exceptions import PkgcoreException, PkgcoreUserException
-from pkgcore.log import logger
-
+from .. import const, os_data
+from ..exceptions import PkgcoreException, PkgcoreUserException
+from ..log import logger
+from . import const as e_const
 
 _global_ebp_lock = threading.Lock()
 inactive_ebp_list = []
@@ -81,6 +78,7 @@ def shutdown_all_processors():
         logger.error(e)
         raise
 
+
 spawn.atexit_register(shutdown_all_processors)
 
 
@@ -157,6 +155,7 @@ def drop_ebuild_processor(ebp):
     except ValueError:
         pass
 
+
 @contextlib.contextmanager
 def reuse_or_request(ebp=None, **kwargs):
     """Do a processor operation, locking as necessary.
@@ -220,18 +219,33 @@ class ProcessorError(PkgcoreUserException):
 
 
 class EbdError(ProcessorError):
-    """Ebuild daemon received a die() call on the bash side."""
+    """Ebuild daemon received a die() call on the bash side.
+
+    This highly depends on the die message format and must be updated if
+    that changes substantially.
+    """
 
     def msg(self, verbosity=0):
         """Extract error message from verbose output depending on verbosity level."""
         if verbosity <= 0:
             # strip ANSI escapes from output
             lines = (bash.ansi_escape_re.sub('', x) for x in self.error.split('\n'))
-            # extract context and die message from bash error output
+            # pull eerror cmd output and strip prefixes
             bash_error = [x.lstrip(' *') for x in lines if x.startswith(' *')]
-            # output specific error message if it exists in the expected format
-            if bash_error:
-                return bash_error[1]
+            try:
+                # output specific error message if it exists in the expected format
+                error = bash_error[1]
+                try:
+                    # add non-helper die context if it exists and is from an eclass
+                    die_context = next(
+                        x for x in reversed(bash_error) if x.endswith('called die'))
+                    if die_context.split(',', 1)[0].endswith('.eclass'):
+                        error += f', ({die_context})'
+                except StopIteration:
+                    pass
+                return error
+            except IndexError:
+                pass
         # show full bash output in verbose mode
         return self.error.strip('\n')
 
@@ -260,6 +274,7 @@ def chuck_KeyboardInterrupt(*args):
         ebp.shutdown_processor(force=True)
     raise KeyboardInterrupt("ctrl+c encountered")
 
+
 signal.signal(signal.SIGINT, chuck_KeyboardInterrupt)
 
 
@@ -276,6 +291,7 @@ def chuck_TermInterrupt(ebp, *args):
         drop_ebuild_processor(ebp)
         ebp.shutdown_processor()
 
+
 signal.signal(signal.SIGTERM, partial(chuck_TermInterrupt, None))
 
 
@@ -284,11 +300,15 @@ def chuck_UnhandledCommand(ebp, line):
     raise UnhandledCommand(line)
 
 
-def chuck_StoppingCommand(val, ebp, *args):
+def chuck_StoppingCommand(ebp, line):
     """Event handler for successful phase/command completion."""
-    if callable(val):
-        val = val(args[0])
-    raise FinishedProcessing(val)
+    args = line.split(' ', 1)
+    if args[0] == 'succeeded':
+        raise FinishedProcessing(True)
+    else:
+        # Note that we want failures missing an error message to raise
+        # IndexError here so they can be fixed on the bash side.
+        raise ProcessorError(args[1])
 
 
 class EbuildProcessor:
@@ -788,11 +808,7 @@ class EbuildProcessor:
             updates = set()
         commands = extra_commands.copy()
         commands["request_inherit"] = partial(inherit_handler, eclass_cache, updates=updates)
-        val = self.generic_handler(additional_commands=commands)
-
-        if not val:
-            raise ProcessorError(f"returned val from {command} was '{val}'")
-
+        self.generic_handler(additional_commands=commands)
         if updates:
             self.preload_eclasses(eclass_cache, limited_to=updates, async_req=True)
 
@@ -886,12 +902,10 @@ class EbuildProcessor:
             handlers[x] = f
         del f
 
-        handlers["phases"] = partial(
-            chuck_StoppingCommand, lambda f: f.lower().strip() == "succeeded")
-
         handlers["SIGINT"] = chuck_KeyboardInterrupt
         handlers["SIGTERM"] = chuck_TermInterrupt
         handlers["dying"] = chuck_DyingInterrupt
+        handlers["phases"] = chuck_StoppingCommand
 
         if additional_commands is not None:
             for x in additional_commands:
@@ -929,6 +943,7 @@ class EbuildProcessor:
         finally:
             self.unlock()
 
+
 def inherit_handler(ecache, ebp, line=None, updates=None):
     """Callback for implementing inherit digging into eclass_cache.
 
