@@ -8,33 +8,34 @@ __all__ = (
     "Project", "ProjectMember", "Subproject", "ProjectsXml", "LocalProjectsXml"
 )
 
-from collections import namedtuple
 import errno
-from itertools import chain
-from lxml import etree
 import os
 import platform
 import subprocess
+from collections import namedtuple
+from itertools import chain
 from sys import intern
 
+from lxml import etree
 from snakeoil import klass, mappings
 from snakeoil.bash import BashParseError, iter_read_bash, read_dict
 from snakeoil.caching import WeakInstMeta
 from snakeoil.currying import post_curry
 from snakeoil.fileutils import readfile, readlines
-from snakeoil.osutils import pjoin, listdir_files, listdir
+from snakeoil.osutils import listdir, listdir_files, pjoin
 from snakeoil.osutils.mount import umount
 from snakeoil.process.namespaces import simple_unshare
 from snakeoil.sequences import iter_stable_unique
 from snakeoil.strings import pluralism
 
-from pkgcore.config.hint import ConfigHint
-from pkgcore.ebuild import atom, profiles, pkg_updates
-from pkgcore.ebuild.eapi import get_eapi
-from pkgcore.exceptions import PermissionDenied
-from pkgcore.log import logger
-from pkgcore.repository import syncable, errors as repo_errors
-from pkgcore.restrictions import packages
+from ..config.hint import ConfigHint
+from ..exceptions import PermissionDenied
+from ..log import logger
+from ..repository import errors as repo_errors
+from ..repository import syncable
+from ..restrictions import packages
+from . import atom, pkg_updates, profiles
+from .eapi import get_eapi
 
 
 class Maintainer:
@@ -685,19 +686,19 @@ class RepoConfig(syncable.tree, klass.ImmutableInstance, metaclass=WeakInstMeta)
         })
 
     def __init__(self, location, config_name=None, syncer=None, profiles_base='profiles'):
+        super().__init__(syncer)
         object.__setattr__(self, 'config_name', config_name)
         object.__setattr__(self, 'location', location)
         object.__setattr__(self, 'profiles_base', pjoin(self.location, profiles_base))
 
-        if not self.eapi.is_supported:
-            raise repo_errors.UnsupportedRepo(self)
-
-        super().__init__(syncer)
         try:
             self._parse_config()
         except OSError as e:
             raise repo_errors.InitializationError(str(e))
 
+        if not self.eapi.is_supported:
+            raise repo_errors.UnsupportedRepo(self)
+
     def _parse_config(self):
         """Load data from the repo's metadata/layout.conf file."""
         path = pjoin(self.location, self.layout_offset)
@@ -917,8 +918,9 @@ class RepoConfig(syncable.tree, klass.ImmutableInstance, metaclass=WeakInstMeta)
         """
         if self.config_name:
             return self.config_name
-        if self.repo_name:
-            return self.repo_name
+        # repo_name might not be parsed yet if failure occurs during init
+        if repo_name := getattr(self, 'repo_name', None):
+            return repo_name
         if self.pms_repo_name:
             return self.pms_repo_name
         if not self.is_empty:
@@ -945,7 +947,8 @@ class RepoConfig(syncable.tree, klass.ImmutableInstance, metaclass=WeakInstMeta)
 
     @klass.jit_attr
     def base_profile(self):
-        return profiles.EmptyRootNode(self.profiles_base)
+        pms_strict = 'pms' in self.profile_formats
+        return profiles.EmptyRootNode(self.profiles_base, pms_strict=pms_strict)
 
     @klass.jit_attr
     def eapi(self):
