@@ -1,16 +1,14 @@
 """display package keywords"""
 
-from functools import partial
 import os
+from functools import partial
 
-from snakeoil.osutils import pjoin
 from snakeoil.strings import pluralism as _pl
 
-from pkgcore import const
-from pkgcore._vendor.tabulate import tabulate, tabulate_formats
-from pkgcore.ebuild import restricts
-from pkgcore.util import commandline, packages as pkgutils
-
+from .._vendor.tabulate import tabulate, tabulate_formats
+from ..ebuild import restricts
+from ..util import commandline
+from ..util import packages as pkgutils
 
 argparser = commandline.ArgumentParser(description=__doc__, script=(__file__, __name__))
 argparser.add_argument(
