@@ -14,23 +14,23 @@ __all__ = (
 )
 
 import argparse
-from functools import partial
-from importlib import import_module
 import os
 import sys
+from functools import partial
+from importlib import import_module
 
 from snakeoil import modules
 from snakeoil.cli import arghparse, tool
 from snakeoil.log import suppress_logging
-from snakeoil.osutils import pjoin, abspath, normpath
+from snakeoil.osutils import abspath, normpath, pjoin
 from snakeoil.sequences import iflatten_instance, unstable_unique
 from snakeoil.strings import pluralism
 
-from pkgcore.config import basics, load_config
-from pkgcore.plugin import get_plugins
-from pkgcore.repository import errors as repo_errors
-from pkgcore.restrictions import packages, restriction
-from pkgcore.util import parserestrict
+from ..config import basics, load_config
+from ..plugin import get_plugins
+from ..repository import errors as repo_errors
+from ..restrictions import packages, restriction
+from . import parserestrict
 
 
 class StoreTarget(argparse._AppendAction):
